/**
 * apeman task to compile scss files.
 * @memberof module:apeman-task-scss/lib
 * @function define
 * @param {string} src - Source file path.
 * @param {string} dest - Destination file path.
 * @param {options} [options] - Optional settings.
 * @param {string|boolean} [options.sourceMap=dest+'.map'] - Source map file path.
 * @returns {function} - Defined task function.
 */

'use strict'

const fs = require('fs')
const apeCompiling = require('ape-compiling')
const co = require('co')

/** @lends define */
function define (src, dest, options = {}) {
  /**
   * Defined task.
   * @function task
   * @param {object} context - Apeman task context.
   * @returns {Promise}
   */
  function task (context) {
    let { logger } = context

    return co(function * () {
      let exists = yield new Promise((resolve) =>
        fs.exists(src, (exists) => resolve(exists))
      )

      if (!exists) {
        console.warn(`[apeman-task-scss] src not found: ${src}`)
        return
      }

      return apeCompiling.compileScss(src, dest, {
        sourceMap: options.sourceMap
      })
    })
  }

  Object.assign(task, {
    $desc: 'Compile scss files.'
  })
  return task
}

module.exports = define
